@@ -7,7 +7,6 @@ from trytond.model import ModelSQL, ModelView, fields
 from trytond.transaction import Transaction
 
 __all__ = ['RelationType', 'PartyRelation', 'PartyRelationAll', 'Party']
-__metaclass__ = PoolMeta
 
 
 class RelationType(ModelSQL, ModelView):
@@ -137,7 +136,7 @@ class PartyRelationAll(PartyRelation, ModelView):
                     local_cache.clear()
 
         # Clean cursor cache
-        for cache in Transaction().cursor.cache.itervalues():
+        for cache in Transaction().cache.itervalues():
             if cls.__name__ in cache:
                 for record in all_records:
                     for record_id in (record.id, record.reverse_id):
@@ -178,7 +177,7 @@ class PartyRelationAll(PartyRelation, ModelView):
         Transaction().counter += 1
 
         # Clean cursor cache
-        for cache in Transaction().cursor.cache.values():
+        for cache in Transaction().cache.values():
             for cache in (cache, cache.get('_language_cache', {}).values()):
                 if cls.__name__ in cache:
                     for record in relations:
@@ -190,6 +189,7 @@ class PartyRelationAll(PartyRelation, ModelView):
 
 
 class Party:
+    __metaclass__ = PoolMeta
     __name__ = 'party.party'
 
     relations = fields.One2Many('party.relation.all', 'from_', 'Relations')
